@@ -1,9 +1,8 @@
-PKG_DATA_DIR = "/usr/share/uwsm"
 PROJECT_NAME = "uwsm"
-PROJECT_VERSION = "0.25.3"
+PROJECT_VERSION = "0.26.0"
 BIN_NAME = "uwsm"
 BIN_PATH = "/usr/bin/uwsm"
 SH_BIN = "sh"
 WAITPID_BIN = "waitpid"
 WHIPTAIL_BIN = "whiptail"
-STATIC_UNITS = "True"
+PKG_LIBEXEC_DIR = "/usr/lib/uwsm"
