@@ -20,10 +20,10 @@ quirks_sway() {
 	fi
 
 	# mark additional vars for export on finalize
-	UWSM_FINALIZE_VARNAMES="${UWSM_FINALIZE_VARNAMES}${UWSM_FINALIZE_VARNAMES+: }SWAYSOCK I3SOCK XCURSOR_SIZE XCURSOR_THEME"
+	UWSM_FINALIZE_VARNAMES="${UWSM_FINALIZE_VARNAMES}${UWSM_FINALIZE_VARNAMES:+ }SWAYSOCK I3SOCK XCURSOR_SIZE XCURSOR_THEME"
 	export UWSM_FINALIZE_VARNAMES
 
 	# mark additional vars to wait for
-	UWSM_WAIT_VARNAMES="${UWSM_WAIT_VARNAMES}${UWSM_WAIT_VARNAMES+: }SWAYSOCK"
+	UWSM_WAIT_VARNAMES="${UWSM_WAIT_VARNAMES}${UWSM_WAIT_VARNAMES:+ }SWAYSOCK"
 	export UWSM_WAIT_VARNAMES
 }
